IotaAddress

Struct IotaAddress 

pub struct IotaAddress(/* private fields */);
Unique identifier for an Account on the IOTA blockchain.

An Address is a 32-byte pseudonymous identifier used to uniquely identify an account and asset-ownership on the IOTA blockchain. Often, human-readable addresses are encoded in hexadecimal with a 0x prefix. For example, this is a valid IOTA address: 0x02a212de6a9dfa3a69e22387acfbafbb1a9e591bd9d636e7895dcfc8de05f331.

use iota_sdk_types::Address;

let hex = "0x02a212de6a9dfa3a69e22387acfbafbb1a9e591bd9d636e7895dcfc8de05f331";
let address = Address::from_hex(hex).unwrap();
println!("Address: {}", address);
assert_eq!(hex, address.to_string());

Deriving an Address

Addresses are cryptographically derived from a number of user account authenticators, the simplest of which is an Ed25519PublicKey.

Deriving an address consists of the Blake2b256 hash of the sequence of bytes of its corresponding authenticator, prefixed with a domain-separator (except ed25519, for compatibility reasons). For each other authenticator, this domain-separator is the single byte-value of its SignatureScheme flag. E.g. hash(signature schema flag || authenticator bytes).

Each authenticator has a method for deriving its Address as well as documentation for the specifics of how the derivation is done. See Ed25519PublicKey::derive_address for an example.

Relationship to ObjectIds

ObjectIds and Addresses share the same 32-byte addressable space but are derived leveraging different domain-separator values to ensure that, cryptographically, there won’t be any overlap, e.g. there can’t be a valid Object who’s ObjectId is equal to that of the Address of a user account.

BCS

An Address’s BCS serialized form is defined by the following:

address = 32OCTET

Implementations



impl Address

pub const LENGTH: usize = 32

pub const ZERO: Address

pub const MAX: Address

pub const STD: Address

pub const FRAMEWORK: Address

pub const SYSTEM: Address

pub const GENESIS_BRIDGE: Address

pub const STARDUST: Address

pub const SYSTEM_STATE: Address

pub const CLOCK: Address

pub const AUTHENTICATOR_STATE: Address

pub const RANDOMNESS_STATE: Address

pub const GENESIS_IOTA_BRIDGE: Address

pub const DENY_LIST: Address

pub const fn new(bytes: [u8; 32]) -> Address

pub const fn from_u16(suffix: u16) -> Address

Creates an Address from a u16 suffix by setting the last two bytes.

pub fn is_system_package(&self) -> bool

Checks if the address is one of the system package addresses. The system packages are:

  • STD
  • FRAMEWORK
  • SYSTEM
  • GENESIS_BRIDGE
  • STARDUST

pub fn generate<R>(rng: R) -> Address
where R: RngCore + CryptoRng,

pub fn random() -> Address

pub const fn into_bytes(self) -> [u8; 32]

Return the underlying byte array of a Address.

pub const fn bytes(&self) -> &[u8; 32]

pub const fn as_bytes(&self) -> &[u8]

pub const fn from_object_id(object_id: ObjectId) -> Address

pub fn from_hex<T>(hex: T) -> Result<Address, AddressParseError>
where T: AsRef<[u8]>,

Parses an Address from a full-length hex string (64 hex characters), with or without a 0x prefix. Will return an error if the string is not exactly 64 hex characters long (excluding the 0x prefix).

pub fn from_prefixed_hex<T>(hex: T) -> Result<Address, AddressParseError>
where T: AsRef<[u8]>,

Parses an Address from a full-length hex string (64 hex characters), with a mandatory 0x prefix. Will return an error if the string is not exactly 64 hex characters long (excluding the 0x prefix).

pub fn from_short_hex<T>(hex: T) -> Result<Address, AddressParseError>
where T: AsRef<[u8]>,

Parses an Address from a hex string, with or without a 0x prefix. The string can be of variable length; if it’s shorter than 64 hex characters, it will be left-padded with 0s.

pub fn from_prefixed_short_hex<T>(hex: T) -> Result<Address, AddressParseError>
where T: AsRef<[u8]>,

Parses an Address from a hex string with a mandatory 0x prefix. The string can be of variable length; if it’s shorter than 64 hex characters, it will be left-padded with 0s.

pub fn to_hex(&self) -> String

Returns the string representation of this address in hex format with 0x prefix.

pub fn to_raw_hex(&self) -> String

Returns the string representation of this address in hex format without 0x prefix.

pub fn to_short_hex(&self) -> String

Returns the shortest possible string representation of the address (i.e. with leading zeroes trimmed).

pub fn to_raw_short_hex(&self) -> String

Returns the shortest possible string representation of the address (i.e. with leading zeroes trimmed), without 0x prefix.

pub fn to_canonical_string(&self, with_prefix: bool) -> String

Returns the string representation of this address using the canonical display, with or without a 0x prefix.

pub fn from_bytes<T>(bytes: T) -> Result<Address, AddressParseError>
where T: AsRef<[u8]>,

pub const fn next_lexicographical(&self) -> Address

Returns the next address in byte-increasing order.

pub const fn next_lexicographical_opt(&self) -> Option<Address>

Returns the next address in byte-increasing order, or None if the result would overflow.