Struct ObjectDigest
pub struct ObjectDigest(/* private fields */);Expand description
The digest of an Object.
Implementations
impl ObjectDigest
impl ObjectDigest
pub const ZERO: ObjectDigest
pub const ZERO: ObjectDigest
A constant representing a zero digest.
pub const MIN: ObjectDigest
pub const MIN: ObjectDigest
The lexicographically minimum digest.
pub const MAX: ObjectDigest
pub const MAX: ObjectDigest
The lexicographically maximum digest.
pub const fn new(digest: [u8; 32]) -> ObjectDigest
pub const fn new(digest: [u8; 32]) -> ObjectDigest
Generates a new digest from the provided 32 byte array.
pub fn generate<R>(rng: R) -> ObjectDigest
pub fn generate<R>(rng: R) -> ObjectDigest
Generates a new digest from the provided random number generator.
pub fn random() -> ObjectDigest
pub fn random() -> ObjectDigest
Generates a new random digest.
pub const fn into_digest(self) -> Digest
pub const fn into_digest(self) -> Digest
Returns the underlying Digest.
pub const fn inner(&self) -> &[u8; 32]
pub const fn inner(&self) -> &[u8; 32]
Returns a reference to the inner array representation of this digest.
pub const fn into_inner(self) -> [u8; 32]
pub const fn into_inner(self) -> [u8; 32]
Returns the inner array representation of this digest.
pub fn from_base58<T>(base58: T) -> Result<ObjectDigest, DigestParseError>
pub fn from_base58<T>(base58: T) -> Result<ObjectDigest, DigestParseError>
Decodes a digest from a Base58 encoded string.
pub fn from_bytes(
bytes: impl AsRef<[u8]>,
) -> Result<ObjectDigest, DigestParseError>
pub fn from_bytes( bytes: impl AsRef<[u8]>, ) -> Result<ObjectDigest, DigestParseError>
Generates a digest from bytes.
pub const fn next_lexicographical(&self) -> ObjectDigest
pub const fn next_lexicographical(&self) -> ObjectDigest
Returns the next digest in byte-increasing order.
pub const fn next_lexicographical_opt(&self) -> Option<ObjectDigest>
pub const fn next_lexicographical_opt(&self) -> Option<ObjectDigest>
Returns the next digest in byte-increasing order, or None if the
result would overflow.
impl ObjectDigest
impl ObjectDigest
pub const OBJECT_DELETED: ObjectDigest
pub const OBJECT_DELETED: ObjectDigest
A marker that signifies the object is deleted.
pub const OBJECT_WRAPPED: ObjectDigest
pub const OBJECT_WRAPPED: ObjectDigest
A marker that signifies the object is wrapped into another object.
pub const OBJECT_CANCELLED: ObjectDigest
pub const OBJECT_CANCELLED: ObjectDigest
A marker that signifies the object is cancelled.
pub fn is_alive(&self) -> bool
pub fn is_alive(&self) -> bool
Returns whether the digest represents an object that is neither deleted nor wrapped.
pub fn is_deleted(&self) -> bool
pub fn is_deleted(&self) -> bool
Returns whether the digest represents a deleted object.
pub fn is_wrapped(&self) -> bool
pub fn is_wrapped(&self) -> bool
Returns whether the digest represents an object wrapped in another object.