Struct ObjectID
pub struct ObjectID(/* private fields */);Expand description
An ObjectId is a 32-byte identifier used to uniquely identify an object on
the IOTA blockchain.
Relationship to Address
Addresses and ObjectIds share the same 32-byte addressable space but
are derived leveraging different domain-separator values to ensure,
cryptographically, that there won’t be any overlap, e.g. there can’t be a
valid Object whose ObjectId is equal to that of the Address of a user
account.
BCS
An ObjectId’s BCS serialized form is defined by the following:
object-id = addressImplementations
impl ObjectId
impl ObjectId
pub fn derive_id(digest: Digest, count: u64) -> ObjectId
pub fn derive_id(digest: Digest, count: u64) -> ObjectId
Create an ObjectId from a transaction digest and count.
count is the number of objects that have been created during a
transactions.
pub fn derive_dynamic_child_id(
&self,
key_type_tag: &TypeTag,
key_bytes: &[u8],
) -> ObjectId
pub fn derive_dynamic_child_id( &self, key_type_tag: &TypeTag, key_bytes: &[u8], ) -> ObjectId
Derive an ObjectId for a Dynamic Child Object.
hash(parent || len(key) || key || key_type_tag)
impl ObjectId
impl ObjectId
pub const LENGTH: usize = Address::LENGTH
pub const ZERO: ObjectId
pub const MAX: ObjectId
pub const STD: ObjectId
pub const FRAMEWORK: ObjectId
pub const SYSTEM: ObjectId
pub const GENESIS_BRIDGE: ObjectId
pub const STARDUST: ObjectId
pub const SYSTEM_STATE: ObjectId
pub const CLOCK: ObjectId
pub const AUTHENTICATOR_STATE: ObjectId
pub const RANDOMNESS_STATE: ObjectId
pub const GENESIS_IOTA_BRIDGE: ObjectId
pub const DENY_LIST: ObjectId
pub const fn from_u16(suffix: u16) -> ObjectId
pub const fn from_u16(suffix: u16) -> ObjectId
Creates an ObjectId from a u16 suffix by setting the last two bytes.
pub fn is_system_package(&self) -> bool
pub fn is_system_package(&self) -> bool
Checks if the object id is one of the system package ids. The system packages are:
- STD
- FRAMEWORK
- SYSTEM
- GENESIS_BRIDGE
- STARDUST
pub fn to_hex(&self) -> String
pub fn to_hex(&self) -> String
Returns the string representation of this object id in hex format with
0x prefix.
pub fn to_raw_hex(&self) -> String
pub fn to_raw_hex(&self) -> String
Returns the string representation of this object id in hex format
without 0x prefix.
pub fn to_short_hex(&self) -> String
pub fn to_short_hex(&self) -> String
Returns the shortest possible string representation of the object ID (i.e. with leading zeroes trimmed).
pub fn to_raw_short_hex(&self) -> String
pub fn to_raw_short_hex(&self) -> String
Returns the shortest possible string representation of the object id
(i.e. with leading zeroes trimmed), without 0x prefix.
pub fn from_hex<T>(hex: T) -> Result<ObjectId, AddressParseError>
pub fn from_hex<T>(hex: T) -> Result<ObjectId, AddressParseError>
Parses an ObjectId from a full-length hex string (64 hex characters),
with or without a 0x prefix. Will return an error if the string is not
exactly 64 hex characters long (excluding the 0x prefix).
pub fn from_prefixed_hex<T>(hex: T) -> Result<ObjectId, AddressParseError>
pub fn from_prefixed_hex<T>(hex: T) -> Result<ObjectId, AddressParseError>
Parses an ObjectId from a full-length hex string (64 hex characters),
with a mandatory 0x prefix. Will return an error if the string is not
exactly 64 hex characters long (excluding the 0x prefix).
pub fn from_short_hex<T>(hex: T) -> Result<ObjectId, AddressParseError>
pub fn from_short_hex<T>(hex: T) -> Result<ObjectId, AddressParseError>
Parses an ObjectId from a hex string, with or without a 0x prefix.
The string can be of variable length; if it’s shorter than 64 hex
characters, it will be left-padded with 0s.
pub fn from_prefixed_short_hex<T>(hex: T) -> Result<ObjectId, AddressParseError>
pub fn from_prefixed_short_hex<T>(hex: T) -> Result<ObjectId, AddressParseError>
Parses an ObjectId from a hex string with a mandatory 0x prefix.
The string can be of variable length; if it’s shorter than 64 hex
characters, it will be left-padded with 0s.
pub const fn from_address(address: Address) -> ObjectId
pub fn from_bytes<T>(bytes: T) -> Result<ObjectId, AddressParseError>
pub const fn into_bytes(self) -> [u8; 32]
pub const fn into_bytes(self) -> [u8; 32]
Returns the underlying byte array of an ObjectId.
pub const fn bytes(&self) -> &[u8; 32]
pub const fn bytes(&self) -> &[u8; 32]
Returns a reference to the underlying byte array of an ObjectId.
pub const fn as_address(&self) -> &Address
pub const fn as_address(&self) -> &Address
Returns the underlying Address of an ObjectId.
pub fn to_canonical_string(&self, with_prefix: bool) -> String
pub fn to_canonical_string(&self, with_prefix: bool) -> String
Returns the string representation of this object ID using the
canonical display, with or without a 0x prefix.
pub const fn next_lexicographical(&self) -> ObjectId
pub const fn next_lexicographical(&self) -> ObjectId
Returns the next object id in byte-increasing order.
pub const fn next_lexicographical_opt(&self) -> Option<ObjectId>
pub const fn next_lexicographical_opt(&self) -> Option<ObjectId>
Returns the next object id in byte-increasing order, or None if the
result would overflow.
pub fn generate<R>(rng: R) -> ObjectId
pub fn random() -> ObjectId