Struct ObjectRef
pub struct ObjectRef {
pub object_id: ObjectId,
pub version: Version,
pub digest: Digest,
}Expand description
Reference to an object
Contains sufficient information to uniquely identify a specific object.
BCS
The BCS serialized form for this type is defined by the following ABNF:
object-reference = object-id u64 digestFields
object_id: ObjectIdThe object id of this object.
version: VersionThe version of this object.
digest: DigestThe digest of this object.
Implementations
impl ObjectReference
impl ObjectReference
pub const fn new(
object_id: ObjectId,
version: Version,
digest: Digest,
) -> ObjectReference
pub const fn new( object_id: ObjectId, version: Version, digest: Digest, ) -> ObjectReference
Creates a new object reference from the object’s id, version, and digest.
pub fn object_id(&self) -> &ObjectId
pub fn object_id(&self) -> &ObjectId
Returns a reference to the object id that this ObjectReference is referring to.
pub fn version(&self) -> Version
pub fn version(&self) -> Version
Returns the version of the object that this ObjectReference is referring to.
pub fn digest(&self) -> &Digest
pub fn digest(&self) -> &Digest
Returns the digest of the object that this ObjectReference is referring to.
pub fn into_parts(self) -> (ObjectId, Version, Digest)
pub fn into_parts(self) -> (ObjectId, Version, Digest)
Returns a 3-tuple containing the object id, version, and digest.