Struct TransactionDigest
pub struct TransactionDigest(/* private fields */);Expand description
The digest of a Transaction.
Implementations
impl TransactionDigest
impl TransactionDigest
pub const ZERO: TransactionDigest
pub const ZERO: TransactionDigest
A constant representing a zero digest.
pub const MIN: TransactionDigest
pub const MIN: TransactionDigest
The lexicographically minimum digest.
pub const MAX: TransactionDigest
pub const MAX: TransactionDigest
The lexicographically maximum digest.
pub const fn new(digest: [u8; 32]) -> TransactionDigest
pub const fn new(digest: [u8; 32]) -> TransactionDigest
Generates a new digest from the provided 32 byte array.
pub fn generate<R>(rng: R) -> TransactionDigest
pub fn generate<R>(rng: R) -> TransactionDigest
Generates a new digest from the provided random number generator.
pub fn random() -> TransactionDigest
pub fn random() -> TransactionDigest
Generates a new random digest.
pub const fn into_digest(self) -> Digest
pub const fn into_digest(self) -> Digest
Returns the underlying Digest.
pub const fn inner(&self) -> &[u8; 32]
pub const fn inner(&self) -> &[u8; 32]
Returns a reference to the inner array representation of this digest.
pub const fn into_inner(self) -> [u8; 32]
pub const fn into_inner(self) -> [u8; 32]
Returns the inner array representation of this digest.
pub fn from_base58<T>(base58: T) -> Result<TransactionDigest, DigestParseError>
pub fn from_base58<T>(base58: T) -> Result<TransactionDigest, DigestParseError>
Decodes a digest from a Base58 encoded string.
pub fn from_bytes(
bytes: impl AsRef<[u8]>,
) -> Result<TransactionDigest, DigestParseError>
pub fn from_bytes( bytes: impl AsRef<[u8]>, ) -> Result<TransactionDigest, DigestParseError>
Generates a digest from bytes.
pub const fn next_lexicographical(&self) -> TransactionDigest
pub const fn next_lexicographical(&self) -> TransactionDigest
Returns the next digest in byte-increasing order.
pub const fn next_lexicographical_opt(&self) -> Option<TransactionDigest>
pub const fn next_lexicographical_opt(&self) -> Option<TransactionDigest>
Returns the next digest in byte-increasing order, or None if the
result would overflow.
impl TransactionDigest
impl TransactionDigest
pub const GENESIS_MARKER: TransactionDigest = Self::ZERO
pub const GENESIS_MARKER: TransactionDigest = Self::ZERO
A digest used to signify the parent transaction was the genesis. Note that this is not the same as the digest of the genesis transaction, which cannot be known ahead of time.
pub const fn genesis_marker() -> TransactionDigest
pub const fn genesis_marker() -> TransactionDigest
Returns the digest used to signify the parent transaction was the genesis.