Struct TransactionEffectsDigest
pub struct TransactionEffectsDigest(/* private fields */);Expand description
The digest of TransactionEffects.
Implementations
impl TransactionEffectsDigest
impl TransactionEffectsDigest
pub const ZERO: TransactionEffectsDigest
pub const ZERO: TransactionEffectsDigest
A constant representing a zero digest.
pub const MIN: TransactionEffectsDigest
pub const MIN: TransactionEffectsDigest
The lexicographically minimum digest.
pub const MAX: TransactionEffectsDigest
pub const MAX: TransactionEffectsDigest
The lexicographically maximum digest.
pub const fn new(digest: [u8; 32]) -> TransactionEffectsDigest
pub const fn new(digest: [u8; 32]) -> TransactionEffectsDigest
Generates a new digest from the provided 32 byte array.
pub fn generate<R>(rng: R) -> TransactionEffectsDigest
pub fn generate<R>(rng: R) -> TransactionEffectsDigest
Generates a new digest from the provided random number generator.
pub fn random() -> TransactionEffectsDigest
pub fn random() -> TransactionEffectsDigest
Generates a new random digest.
pub const fn into_digest(self) -> Digest
pub const fn into_digest(self) -> Digest
Returns the underlying Digest.
pub const fn inner(&self) -> &[u8; 32]
pub const fn inner(&self) -> &[u8; 32]
Returns a reference to the inner array representation of this digest.
pub const fn into_inner(self) -> [u8; 32]
pub const fn into_inner(self) -> [u8; 32]
Returns the inner array representation of this digest.
pub fn from_base58<T>(
base58: T,
) -> Result<TransactionEffectsDigest, DigestParseError>
pub fn from_base58<T>( base58: T, ) -> Result<TransactionEffectsDigest, DigestParseError>
Decodes a digest from a Base58 encoded string.
pub fn from_bytes(
bytes: impl AsRef<[u8]>,
) -> Result<TransactionEffectsDigest, DigestParseError>
pub fn from_bytes( bytes: impl AsRef<[u8]>, ) -> Result<TransactionEffectsDigest, DigestParseError>
Generates a digest from bytes.
pub const fn next_lexicographical(&self) -> TransactionEffectsDigest
pub const fn next_lexicographical(&self) -> TransactionEffectsDigest
Returns the next digest in byte-increasing order.
pub const fn next_lexicographical_opt(&self) -> Option<TransactionEffectsDigest>
pub const fn next_lexicographical_opt(&self) -> Option<TransactionEffectsDigest>
Returns the next digest in byte-increasing order, or None if the
result would overflow.