Struct MoveObjectType
pub struct MoveObjectType(/* private fields */);Expand description
A StructTag with optimized BCS serialization for object types.
GasCoin, StakedIota, and Coin variants use compact enum encoding instead of the full StructTag representation. The Other variant carries the full StructTag inline.
BCS
compressed-struct-tag = other-struct-type / gas-coin-type / staked-iota-type / coin-type
other-struct-type = %x00 struct-tag
gas-coin-type = %x01
staked-iota-type = %x02
coin-type = %x03 type-tagImplementations
impl MoveObjectType
impl MoveObjectType
pub fn new(tag: StructTag) -> MoveObjectType
pub fn into_inner(self) -> StructTag
Methods from Deref<Target = StructTag>
pub fn is_same_type_as(&self, other: &StructTag) -> bool
pub fn is_same_type_as(&self, other: &StructTag) -> bool
Returns whether the type (excluding the type params) is the same as another struct tag.
pub fn is_gas_coin(&self) -> bool
pub fn is_gas_coin(&self) -> bool
Checks if this is a framework gas coin type
(0x2::coin::Coin<0x2::iota::IOTA>)
pub fn is_name(&self) -> bool
pub fn is_name(&self) -> bool
Checks if this is an IOTA-Names Name type.
Note that this does not check the package address, so it will return
true for any struct with the correct module and type name with no
type params.
pub fn is_dynamic_field(&self) -> bool
pub fn is_dynamic_field(&self) -> bool
Checks if this is a Dynamic Field type
(0x2::dynamic_field::Field<KeyType, ValueType>)
pub fn coin_type_opt(&self) -> Option<&TypeTag>
pub fn coin_type_opt(&self) -> Option<&TypeTag>
Returns the coin type if this is a Coin type, None otherwise
pub fn module(&self) -> &Identifier
pub fn module(&self) -> &Identifier
Returns the module part of a StructTag
pub fn name(&self) -> &Identifier
pub fn name(&self) -> &Identifier
Returns the name part of a StructTag
pub fn type_params(&self) -> &[TypeTag]
pub fn type_params(&self) -> &[TypeTag]
Returns the type params part of a StructTag
pub fn is_timelocked_balance(&self) -> bool
pub fn is_timelocked_balance(&self) -> bool
Checks if this is a timelocked coin balance TimeLock<Balance<T>>
pub fn is_gas_balance(&self) -> bool
pub fn is_gas_balance(&self) -> bool
Checks if this is an IOTA balance type
(0x2::balance::Balance<0x2::iota::IOTA>)
pub fn is_timelocked_gas_balance(&self) -> bool
pub fn is_timelocked_gas_balance(&self) -> bool
Checks if this is a timelocked IOTA balance type
(0x2::timelock::TimeLock<0x2::balance::Balance<0x2::iota::IOTA>>)
pub fn to_canonical_string(&self, with_prefix: bool) -> String
pub fn to_canonical_string(&self, with_prefix: bool) -> String
Returns the string representation of this struct tag using the
canonical display, with or without a 0x prefix.
pub fn is_authenticator_state(&self) -> bool
pub fn is_clock(&self) -> bool
pub fn is_config(&self) -> bool
pub fn is_iota_treasury_cap(&self) -> bool
pub fn is_upgrade_cap(&self) -> bool
pub fn is_upgrade_ticket(&self) -> bool
pub fn is_upgrade_receipt(&self) -> bool
pub fn is_random(&self) -> bool
pub fn is_iota_system_admin_cap(&self) -> bool
pub fn is_url(&self) -> bool
pub fn is_bag(&self) -> bool
pub fn is_object_bag(&self) -> bool
pub fn is_tx_context(&self) -> bool
pub fn is_deny_list_config_key(&self) -> bool
pub fn is_deny_list_address_key(&self) -> bool
pub fn is_deny_list_global_pause_key(&self) -> bool
pub fn is_transfer_receiving(&self) -> bool
pub fn is_iota_system_state(&self) -> bool
pub fn is_staked_iota(&self) -> bool
pub fn is_timelocked_staked_iota(&self) -> bool
pub fn is_system_epoch_info_event(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_ascii_string(&self) -> bool
pub fn is_regulated_coin_metadata(&self) -> bool
pub fn is_deny_cap_v1(&self) -> bool
pub fn is_coin_metadata(&self) -> bool
pub fn is_treasury_cap(&self) -> bool
pub fn is_coin_manager(&self) -> bool
pub fn is_display_created(&self) -> bool
pub fn is_display_version_updated(&self) -> bool
pub fn is_coin(&self) -> bool
pub fn is_balance(&self) -> bool
pub fn is_time_lock(&self) -> bool
pub fn is_config_setting(&self) -> bool
pub fn is_dynamic_object_field_wrapper(&self) -> bool
pub fn is_option(&self) -> bool